==> lcfm_shapefiles-0.3.2-py3-none-any.whl: lcfm_shapefiles/products.py <==
import enum
from datetime import datetime
from typing import ClassVar

import numpy as np

from lcfm_shapefiles.labels import LCM10LabelsColors

class LCM10Layer(enum.Enum):
    MAP = "MAP"
    MAP_CONTINUOUS = "MAP_CONTINUOUS"
    PROBABILITY = "PROBABILITY"

class LCM10Product:
    """Class representing the Land Cover Map 10m product."""
    # Using ClassVar to indicate these are class variables, not instance variables
    nodata: ClassVar[int] = LCM10LabelsColors.NO_DATA.id
    data_type: ClassVar[type] = np.uint8
    
    def __init__(self, version: str, year: int = 2020):
        """Initialize LCM10 with a version and optional year.
        
        Args:
            version: Version string in the format 'vXXX' where X is a digit
            year: The year for the product, defaults to 2020
        
        Raises:
            ValueError: If version doesn't follow the required format
        """
        # Assert that version follows the vxxx pattern
        if not version.startswith("v") or not version[1:].isdigit() or (len(version) != 4):
            raise ValueError("Version must start with 'v' followed by 3 digits.")
        # Set the version and year
        self.version = version
        self.year = year

    def get_metadata(self, layer: LCM10Layer, tile_id: str):
        """Generate metadata for a Land Cover Map 10m product.
        
        Args:
            layer: The type of layer (MAP, MAP_CONTINUOUS, PROBABILITY)
            tile_id: The tile identifier
            
        Returns:
            A dictionary containing the metadata
        """
        generation_time = datetime.now().strftime("%Y-%m-%dT%H:%M:%SZ")

        metadata = dict(
            copyright=(
                f"LCFM project {self.year} / Contains modified "
                f"Copernicus Sentinel data ({self.year}) processed by "
                "LCFM consortium"
            ),
            creation_time=generation_time,
            description="Land Cover Map - 10m",
            doi="undefined",
            license="CC-BY 4.0 - https://creativecommons.org/licenses/by/4.0/",
            platform="Sentinel 1, Sentinel 2",
            producer="VITO NV",
            product_crs="EPSG:4326",
            product_grid="3x3 degree tiling grid",
            product_layer=f"{layer.value.replace('_', '-')}",
            product_tile=tile_id,
            reference="https://land.copernicus.eu",
            sensor="SAR, MSI",
            time_start=f"{self.year}-01-01T00:00:00Z",
            time_end=f"{self.year}-12-31T23:59:59Z",
            version=self.version,
        )
        return metadata

==> lcfm_shapefiles-0.3.3.dev20250423+31-py3-none-any.whl: lcfm_shapefiles/products.py <==
import enum
from datetime import datetime
from typing import ClassVar

import numpy as np

from lcfm_shapefiles.labels import LCM10LabelsColors

class Product():

    def __init__(self, version: str, year: int = 2020):
        """Initialize Product with a version and optional year.
        
        Args:
            version: Version string in the format 'vXXX' where X is a digit
            year: The year for the product, defaults to 2020
        
        Raises:
            ValueError: If version doesn't follow the required format
        """
        # Assert that version follows the vxxx pattern
        if not version.startswith("v") or not version[1:].isdigit() or (len(version) != 4):
            raise ValueError("Version must start with 'v' followed by 3 digits.")
        # Set the version and year
        self.version = version
        self.year = year

    def get_metadata(self, layer: enum.Enum, tile_id: str, tile_size: int = 3, resolution: int = 10):
        """Generate metadata for a Land Cover Map 10m product.
        
        Args:
            layer: The type of layer (MAP, MAP_CONTINUOUS, PROBABILITY)
            tile_id: The tile identifier
            
        Returns:
            A dictionary containing the metadata
        """
        generation_time = datetime.now().strftime("%Y-%m-%dT%H:%M:%SZ")

        metadata = dict(
            copyright=(
                f"LCFM project {self.year} / Contains modified "
                f"Copernicus Sentinel data ({self.year}) processed by "
                "LCFM consortium"
            ),
            creation_time=generation_time,
            description=f"Land Cover Map - {resolution}m",
            doi="undefined",
            license="CC-BY 4.0 - https://creativecommons.org/licenses/by/4.0/",
            platform="Sentinel-1, Sentinel-2",
            producer="VITO NV",
            product_crs="EPSG:4326",
            product_grid=f"{tile_size}x{tile_size} degree tiling grid",
            product_layer=f"{layer.value.replace('_', '-')}",
            product_tile=tile_id,
            reference="https://land.copernicus.eu",
            sensor="SAR, MSI",
            time_start=f"{self.year}-01-01T00:00:00Z",
            time_end=f"{self.year}-12-31T23:59:59Z",
            version=self.version,
        )
        return metadata

class LCM10Layer(enum.Enum):
    MAP = "MAP"
    MAP_CONTINUOUS = "MAP_CONTINUOUS"
    PROBABILITY = "PROBABILITY"

class LCM10Product(Product):
    """Class representing the Land Cover Map 10m product."""
    # Using ClassVar to indicate these are class variables, not instance variables
    nodata: ClassVar[int] = LCM10LabelsColors.NO_DATA.id
    data_type: ClassVar[type] = np.uint8

    def get_metadata(self, layer: LCM10Layer, tile_id: str):
        """Generate metadata for a Land Cover Map 10m product.
        
        Args:
            layer: The type of layer (MAP, MAP_CONTINUOUS, PROBABILITY)
            tile_id: The tile identifier
            
        Returns:
            A dictionary containing the metadata
        """
        return super().get_metadata(layer, tile_id)

class LCM100Layer(enum.Enum):
    MAP = "MAP"
    CFRAC = "CFRAC"
    CHANGE = "CHANGE"

class LCM100Product(Product):
    """Class representing the Land Cover Map 100 product."""
    # Using ClassVar to indicate these are class variables, not instance variables
    nodata: ClassVar[int] = 255
    data_type: ClassVar[type] = np.uint8

    def get_metadata(self, layer: LCM100Layer, tile_id: str):
        """Generate metadata for a Land Cover Map 10m product.
        
        Args:
            layer: The type of layer (MAP, MAP_CONTINUOUS, PROBABILITY)
            tile_id: The tile identifier
            
        Returns:
            A dictionary containing the metadata
        """
        return super().get_metadata(layer, tile_id, tile_size=30, resolution=100)
